package com.sd.business.service.order.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.wrapper.IWrapper;
import com.sd.business.entity.bom.po.BomSpec;
import com.sd.business.entity.department.po.Department;
import com.sd.business.entity.order.dto.OrderSkuDto;
import com.sd.business.entity.order.dto.OrderSkuSelectDto;
import com.sd.business.entity.order.po.OrderInfo;
import com.sd.business.entity.order.po.OrderOperatingLog;
import com.sd.business.entity.order.po.OrderSku;
import com.sd.business.entity.order.vo.OrderSkuVo;
import com.sd.business.entity.sku.po.SkuSpec;
import com.sd.business.mapper.order.OrderSkuMapper;
import com.sd.business.service.order.OrderOperatingLogService;
import com.sd.business.service.order.OrderSkuService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;


/**
 * <p>
 * 订单sku 服务实现类
 * </p>
 *
 * @author
 * @since 2023-07-06
 */
@Service
public class OrderSkuServiceImpl extends ServiceImpl<OrderSkuMapper, OrderSku> implements OrderSkuService {

    @Autowired
    private OrderOperatingLogService orderOperatingLogService;

    @Override
    public Page<OrderSkuVo> getPage(OrderSkuSelectDto dto) {
        IWrapper<OrderSku> wrapper = getWrapper();
        wrapper.orderByDesc("os", OrderSku::getId);

        wrapper.like("oi", OrderInfo::getCode, dto.getOrderCode());
        wrapper.like("oi", OrderInfo::getWlnCode, dto.getOrderWlnCode());
        wrapper.like("d", Department::getName, dto.getDepartmentName());
        wrapper.like("ss", SkuSpec::getCode, dto.getSkuSpecCode());
        wrapper.like("ss", SkuSpec::getName, dto.getSkuSpecName());
        wrapper.like("bs", BomSpec::getCode, dto.getBomSpecCode());
        wrapper.like("bs", BomSpec::getName, dto.getBomSpecName());
        wrapper.eq("oi", OrderInfo::getStatus, dto.getOrderStatus());

        wrapper.ge("oi", OrderInfo::getWlnCreateTime, dto.getBeginTime());
        wrapper.le("oi", OrderInfo::getWlnCreateTime, dto.getEndTime());

        Page<OrderSkuVo> page = this.baseMapper.getPage(dto.getPage(), wrapper);

        return page;
    }

    @Override
    public OrderSkuVo detail(Long id) {
        OrderSku OrderSku = this.getById(id);
        OrderSkuVo result = BeanUtil.toBean(OrderSku, OrderSkuVo.class);
        return result;
    }

    @Override
    public void add(OrderSkuDto orderSkuDto) {
        this.save(orderSkuDto);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OrderSkuDto orderSkuDto) {
        this.updateById(orderSkuDto);
        OrderOperatingLog orderOperatingLog = new OrderOperatingLog();
        orderOperatingLog.setType(orderSkuDto.getUpdateType());
        orderOperatingLog.setOrderId(orderSkuDto.getOrderId());
        orderOperatingLog.setOrderCode(orderSkuDto.getOrderCode());
        orderOperatingLogService.save(orderOperatingLog);
    }

    @Override
    public void delete(Long id) {
        this.removeById(id);
    }

}
