package com.sd.wln.service.impl;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.fjhx.tenant.entity.dict.po.DictCommonData;
import com.fjhx.tenant.service.dict.DictCommonDataService;
import com.ruoyi.common.constant.StatusConstant;
import com.ruoyi.common.core.domain.BaseIdPo;
import com.ruoyi.framework.mybatis.holder.LogicHolder;
import com.sd.business.entity.bom.bo.BomBo;
import com.sd.business.entity.department.po.Department;
import com.sd.business.entity.order.enums.OrderStatusEnum;
import com.sd.business.entity.order.po.OrderInfo;
import com.sd.business.entity.order.po.OrderPackageBom;
import com.sd.business.entity.order.po.OrderSku;
import com.sd.business.entity.order.po.OrderSkuBom;
import com.sd.business.entity.price.po.PriceBillingStandardDetail;
import com.sd.business.entity.sku.po.SkuSpec;
import com.sd.business.entity.sku.po.SkuSpecLink;
import com.sd.business.service.department.DepartmentService;
import com.sd.business.service.order.OrderPackageBomService;
import com.sd.business.service.order.OrderService;
import com.sd.business.service.order.OrderSkuBomService;
import com.sd.business.service.order.OrderSkuService;
import com.sd.business.service.price.PriceBillingStandardDetailService;
import com.sd.business.service.sku.SkuSpecLinkService;
import com.sd.business.service.sku.SkuSpecService;
import com.sd.wln.service.WlnOrderService;
import com.sd.wln.util.WlnUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.PlatformTransactionManager;
import org.springframework.transaction.TransactionDefinition;
import org.springframework.transaction.TransactionStatus;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

@Slf4j
@Service
public class WlnOrderServiceImpl implements WlnOrderService {

    @Autowired
    private PlatformTransactionManager platformTransactionManager;

    @Autowired
    private TransactionDefinition transactionDefinition;

    @Autowired
    private DictCommonDataService dictCommonDataService;

    @Autowired
    private DepartmentService departmentService;

    @Autowired
    private OrderService orderService;

    @Autowired
    private OrderSkuService orderSkuService;

    @Autowired
    private OrderSkuBomService orderSkuBomService;

    @Autowired
    private OrderPackageBomService orderPackageBomService;

    @Autowired
    private SkuSpecService skuSpecService;

    @Autowired
    private PriceBillingStandardDetailService priceBillingStandardDetailService;

    @Autowired
    private SkuSpecLinkService skuSpecLinkService;

    @Override
    public void syncOrder() {

        // 当前时间
        Date endDate = new Date();

        // 保存订单列表
        List<OrderInfo> saveOrderList = new ArrayList<>();
        // 更新订单列表
        List<OrderInfo> updateOrderList = new ArrayList<>();
        // 保存订单明细列表
        List<OrderSku> saveOrderSkuList = new ArrayList<>();
        // 保存订单包材
        List<OrderSkuBom> saveOrderSkuBomList = new ArrayList<>();
        // 保存订单包装
        List<OrderPackageBom> orderPackageBomList = new ArrayList<>();

        // 查询近3天万里牛订单
        List<JSONObject> wlnOrderList = getWlnOrderList(endDate);
        if (wlnOrderList == null || wlnOrderList.size() == 0) {
            return;
        }

        // 不排除逻辑删除的订单
        LogicHolder.setLogicHolder(new LogicHolder());
        // 查询近3天已存在数据库中的订单
        Map<String, OrderInfo> orderMap = orderService.mapKEntity(OrderInfo::getWlnUid,
                q -> q.between(OrderInfo::getWlnApproveTime, DateUtil.offsetDay(endDate, -3), endDate));
        LogicHolder.clear();

        // 查询事业部
        Map<String, Department> departmentMap = getDepartmentMap();

        // 获取sku规格
        Map<String, SkuSpec> skuSpecMap = getSkuSpecMap(wlnOrderList);

        // 循环万里牛订单
        for (JSONObject wlnOrder : wlnOrderList) {

            // 如果订单存在于数据库,且订单状态改变,执行update
            OrderInfo orderInfo = orderMap.get(wlnOrder.getString("uid"));
            if (orderInfo != null) {
                Integer processStatus = wlnOrder.getInteger("process_status");
                if (ObjectUtil.notEqual(orderInfo.getWlnStatus(), processStatus)) {
                    OrderInfo updateOrder = new OrderInfo();
                    updateOrder.setId(orderInfo.getId());
                    updateOrder.setWlnStatus(processStatus);
                    updateOrderList.add(updateOrder);
                }
                continue;
            }

            // 没有匹配到事业部,则跳过
            String storageCode = wlnOrder.getString("storage_code");
            Department department = departmentMap.get(storageCode);
            if (department == null) {
                log.error("未知仓库code：{}", storageCode);
                continue;
            }

            // 创建订单
            orderInfo = createOrder(wlnOrder, department);
            List<OrderSku> tempOrderSkuList = new ArrayList<>();
            List<OrderSkuBom> tempOrderSkuBomList = new ArrayList<>();

            boolean isSave = true;

            // 创建订单sku
            for (JSONObject wlnOrderSku : wlnOrder.getJSONArray("orders").toJavaList(JSONObject.class)) {
                String sysSpecUid = wlnOrderSku.getString("sys_spec_uid");
                SkuSpec skuSpec = skuSpecMap.get(sysSpecUid);
                if (skuSpec == null) {
                    isSave = false;
                    log.error("没有通过万里牛sys_spec_uid: {} 找到sku规格", sysSpecUid);
                    break;
                }

                OrderSku orderSku = createOrderSku(wlnOrderSku, orderInfo, skuSpec);
                tempOrderSkuList.add(orderSku);

                List<OrderSkuBom> orderSkuBomList = createOrderSkuBoom(orderInfo, orderSku);
                tempOrderSkuBomList.addAll(orderSkuBomList);
            }

            if (isSave) {
                saveOrderList.add(orderInfo);
                saveOrderSkuList.addAll(tempOrderSkuList);
                saveOrderSkuBomList.addAll(tempOrderSkuBomList);
                orderPackageBomList.addAll(createOrderPackageBomList(tempOrderSkuList, department.getId()));
            }

        }

        // 赋值订单价格
        setOrderPrice(departmentMap, saveOrderList, saveOrderSkuList, saveOrderSkuBomList, skuSpecMap);

        // 开启事务
        TransactionStatus transactionStatus = platformTransactionManager.getTransaction(transactionDefinition);
        try {
            if (saveOrderList.size() > 0) {
                orderService.saveBatch(saveOrderList);
            }
            if (updateOrderList.size() > 0) {
                orderService.updateBatchById(updateOrderList);
            }
            if (saveOrderSkuList.size() > 0) {
                orderSkuService.saveBatch(saveOrderSkuList);
            }
            if (saveOrderSkuBomList.size() > 0) {
                orderSkuBomService.saveBatch(saveOrderSkuBomList);
            }
            if (orderPackageBomList.size() > 0) {
                orderPackageBomService.saveBatch(orderPackageBomList);
            }
            // 提交事务
            platformTransactionManager.commit(transactionStatus);
        } catch (Exception e) {
            // 回滚事务
            platformTransactionManager.rollback(transactionStatus);
            log.error("同步订单失败", e);
        }

    }

    /**
     * 查询近3天万里牛订单
     */
    private List<JSONObject> getWlnOrderList(Date endDate) {
        List<DictCommonData> warehouseCodeList = dictCommonDataService.list(q -> q.eq(DictCommonData::getDictCode, "warehouse_code"));
        if (warehouseCodeList.size() == 0) {
            log.error("订单同步失败，仓库字典:warehouse_code 为空");
            return null;
        }

        List<JSONObject> list = new ArrayList<>();

        long endTime = endDate.getTime();
        long startTime = endTime - 1000 * 60 * 60 * 24;

        // for (int i = 0; i < 3; i++) {
        for (DictCommonData dictCommonData : warehouseCodeList) {
            int page = 1;
            int size;
            do {
                try {
                    List<JSONObject> itemList = WlnUtil.getOrderList(page, 200, startTime, endTime, dictCommonData.getDictValue());
                    page++;
                    size = itemList.size();
                    list.addAll(itemList);
                } catch (Exception e) {
                    log.error("订单同步失败", e);
                    return null;
                }
            } while (size >= 200);
        }
        //     startTime -= 1000 * 60 * 60 * 24;
        //     endTime -= 1000 * 60 * 60 * 24;
        // }

        return list;
    }

    /**
     * 查询事业部
     */
    private Map<String, Department> getDepartmentMap() {
        List<Department> departmentList = departmentService.list();
        Map<String, Department> departmentMap = new HashMap<>();

        for (Department department : departmentList) {
            String warehouseCode = department.getWlnWarehouseCode();
            if (StrUtil.isBlank(warehouseCode)) {
                continue;
            }
            for (String item : warehouseCode.split(",")) {
                departmentMap.put(item, department);
            }
        }
        return departmentMap;
    }

    /**
     * 获取sku规格
     */
    private Map<String, SkuSpec> getSkuSpecMap(List<JSONObject> wlnOrderList) {
        List<String> wlnUidList = wlnOrderList.stream()
                .flatMap(item -> item.getJSONArray("orders").toJavaList(JSONObject.class).stream())
                .map(item -> item.getString("sys_spec_uid"))
                .filter(ObjectUtil::isNotNull)
                .distinct()
                .collect(Collectors.toList());
        return skuSpecService.mapKEntity(SkuSpec::getWlnUid, q -> q.in(SkuSpec::getWlnUid, wlnUidList));
    }

    /**
     * 创建订单
     */
    private OrderInfo createOrder(JSONObject wlnOrder, Department department) {
        OrderInfo orderInfo = new OrderInfo();
        orderInfo.setId(IdWorker.getId());
        orderInfo.setSource(2);
        orderInfo.setCode(wlnOrder.getString("tp_tid"));
        orderInfo.setWlnCode(wlnOrder.getString("trade_no"));
        orderInfo.setWlnStatus(wlnOrder.getInteger("process_status"));
        orderInfo.setWlnUid(wlnOrder.getString("uid"));
        orderInfo.setModifyTime(wlnOrder.getLong("modify_time"));
        orderInfo.setWlnCreateTime(wlnOrder.getDate("create_time"));
        orderInfo.setWlnApproveTime(wlnOrder.getDate("approve_time"));
        orderInfo.setWlnPrintTime(wlnOrder.getDate("print_time"));
        orderInfo.setWlnStorageCode(wlnOrder.getString("storage_code"));
        orderInfo.setDeliveryTime(DateUtil.offsetDay(orderInfo.getWlnCreateTime(), 1));
        orderInfo.setProvince(wlnOrder.getString("province"));
        orderInfo.setCity(wlnOrder.getString("city"));
        orderInfo.setCounty(wlnOrder.getString("district"));
        orderInfo.setDetailedAddress(wlnOrder.getString("address"));
        orderInfo.setPostcode(wlnOrder.getString("zip"));
        orderInfo.setDepartmentId(department.getId());
        orderInfo.setRemark(wlnOrder.getString("remark"));
        orderInfo.setTaxRate(new BigDecimal("10.00"));
        orderInfo.setTag("0");
        orderInfo.setSettlementStatus(1);

        StringBuilder builder = new StringBuilder();
        // 订单来源平台
        if (wlnOrder.containsKey("source_platform")) {
            builder.append(wlnOrder.getString("source_platform"));
        }
        // 店铺名称
        if (wlnOrder.containsKey("shop_name")) {
            builder.append("_");
            builder.append(wlnOrder.getString("shop_name"));
        }
        orderInfo.setCommercePlatform(builder.toString());

        if (orderInfo.getWlnStatus() == 10 || orderInfo.getWlnStatus() == 11 || orderInfo.getWlnStatus() == 12) {
            orderInfo.setStatus(OrderStatusEnum.EXCEPTION.getKey());
        } else if (Objects.equals(department.getOrderMode(), "2")) {
            orderInfo.setStatus(OrderStatusEnum.STOCK_PREPARATION.getKey());
        } else {
            orderInfo.setStatus(OrderStatusEnum.UNDER_REVIEW.getKey());
        }

        return orderInfo;
    }

    /**
     * 创建订单sku
     */
    private OrderSku createOrderSku(JSONObject wlnOrderSku, OrderInfo orderInfo, SkuSpec skuSpec) {
        OrderSku orderSku = new OrderSku();
        orderSku.setId(IdWorker.getId());
        orderSku.setOrderId(orderInfo.getId());
        orderSku.setQuantity(wlnOrderSku.getBigDecimal("size"));
        orderSku.setPrintType(1);
        orderSku.setWlnSkuId(wlnOrderSku.getString("sys_goods_uid"));
        orderSku.setWlnSkuSpecId(wlnOrderSku.getString("sys_spec_uid"));
        orderSku.setWlnSkuName(wlnOrderSku.getString("oln_sku_name"));
        orderSku.setSkuId(skuSpec.getSkuId());
        orderSku.setSkuSpecId(skuSpec.getId());
        orderSku.setStockPreparationStatus(StatusConstant.NO);
        return orderSku;
    }

    /**
     * 创建订单包材
     */
    private List<OrderSkuBom> createOrderSkuBoom(OrderInfo orderInfo, OrderSku orderSku) {

        List<SkuSpecLink> list = skuSpecLinkService.list(q -> q
                .eq(SkuSpecLink::getSkuSpecId, orderSku.getSkuSpecId())
                .eq(SkuSpecLink::getType, 1)
                .eq(SkuSpecLink::getDepartmentId, orderInfo.getDepartmentId())
        );

        if (list.size() == 0) {
            return Collections.emptyList();
        }

        // 根据sku规格id获取bomId和bom规格id
        List<Long> skuSpecIdList = list.stream().map(SkuSpecLink::getSkuSpecId).collect(Collectors.toList());
        Map<Long, BomBo> bomBoMap = skuSpecService.getBomBySkuSpecIdList(skuSpecIdList);

        return list.stream().map(item -> {
            OrderSkuBom orderSkuBom = new OrderSkuBom();
            orderSkuBom.setId(IdWorker.getId());
            orderSkuBom.setOrderId(orderInfo.getId());
            orderSkuBom.setOrderSkuId(orderSku.getId());
            orderSkuBom.setBomSpecId(item.getBomSpecId());
            orderSkuBom.setQuantity(item.getQuantity());

            BomBo bomBo = bomBoMap.get(item.getBomSpecId());
            if (bomBo == null) {
                orderSkuBom.setUnitPrice(BigDecimal.ZERO);
            } else {
                orderSkuBom.setUnitPrice(ObjectUtil.defaultIfNull(bomBo.getInternalSellingPrice(), BigDecimal.ZERO));
            }

            return orderSkuBom;
        }).collect(Collectors.toList());
    }


    private List<OrderPackageBom> createOrderPackageBomList(List<OrderSku> orderSkuList, Long departmentId) {

        // 获取sku规格快递包材map
        List<Long> skuSpecIdList = orderSkuList.stream().map(OrderSku::getSkuSpecId).collect(Collectors.toList());
        List<SkuSpecLink> list = skuSpecLinkService.list(q -> q
                .in(SkuSpecLink::getSkuSpecId, skuSpecIdList)
                .eq(SkuSpecLink::getType, 2)
                .eq(SkuSpecLink::getDepartmentId, departmentId)
        );
        Map<Long, List<SkuSpecLink>> skuSpecLinkMap = list.stream().collect(Collectors.groupingBy(SkuSpecLink::getSkuSpecId));


        Map<Long, OrderPackageBom> orderPackageBomMap = new HashMap<>();

        // 循环订单sku规格
        for (OrderSku orderSku : orderSkuList) {

            List<SkuSpecLink> skuSpecLinkList = skuSpecLinkMap.get(orderSku.getSkuSpecId());
            if (ObjectUtil.isEmpty(skuSpecLinkList)) {
                continue;
            }

            for (SkuSpecLink skuSpecLink : skuSpecLinkList) {

                Long bomSpecId = skuSpecLink.getBomSpecId();
                OrderPackageBom orderPackageBom = orderPackageBomMap.computeIfAbsent(bomSpecId, item -> {
                    OrderPackageBom tempOrderPackageBom = new OrderPackageBom();
                    tempOrderPackageBom.setOrderId(orderSku.getOrderId());
                    tempOrderPackageBom.setBomSpecId(bomSpecId);
                    tempOrderPackageBom.setQuantity(BigDecimal.ZERO);
                    return tempOrderPackageBom;
                });

                orderPackageBom.setQuantity(orderPackageBom.getQuantity().add(orderSku.getQuantity().multiply(skuSpecLink.getQuantity())));

            }
        }

        return new ArrayList<>(orderPackageBomMap.values());
    }

    /**
     * 赋值订单价格
     */
    private void setOrderPrice(Map<String, Department> departmentMap,
                               List<OrderInfo> orderList,
                               List<OrderSku> orderSkuList,
                               List<OrderSkuBom> saveOrderSkuBomList,
                               Map<String, SkuSpec> skuSpecMap) {

        if (orderList.size() == 0 || orderSkuList.size() == 0) {
            return;
        }

        // 部门id、加工计费标准id map
        Map<Long, Long> departmentIdPriceBillingStandardIdMap = departmentMap.values()
                .stream()
                .filter(ObjectUtil::isNotNull)
                .filter(item -> ObjectUtil.isNotNull(item.getPriceBillingStandardId()))
                .collect(Collectors.toMap(BaseIdPo::getId, Department::getPriceBillingStandardId));

        // 加工计费标准id 报价规则列表 map
        Map<Long, List<PriceBillingStandardDetail>> priceBillingStandardMap =
                priceBillingStandardDetailService.list().stream()
                        .filter(item -> ObjectUtil.isNotNull(item.getPriceBillingStandardId()))
                        .collect(Collectors.groupingBy(PriceBillingStandardDetail::getPriceBillingStandardId));

        // 根据sku规格id获取bomId和bom规格id
        Map<Long, BomBo> bomBoMap = skuSpecService.getBomBySkuSpecIdList(
                orderSkuList.stream().map(OrderSku::getSkuSpecId).collect(Collectors.toList()));

        // 订单明细
        Map<Long, List<OrderSku>> orderSkuGroup = orderSkuList.stream().collect(Collectors.groupingBy(OrderSku::getOrderId));

        for (OrderInfo orderInfo : orderList) {

            orderInfo.setTotalAmount(BigDecimal.ZERO);
            orderInfo.setProductTotalAmount(BigDecimal.ZERO);
            orderInfo.setCustomProcessingFee(BigDecimal.ZERO);
            orderInfo.setLssueFee(BigDecimal.ZERO);
            orderInfo.setDeliveryMaterialsFee(BigDecimal.ZERO);
            orderInfo.setPackingLabor(BigDecimal.ZERO);
            orderInfo.setPackagingMaterialCost(BigDecimal.ZERO);

            List<OrderSku> itemOrderSkuList = orderSkuGroup.get(orderInfo.getId());
            if (ObjectUtil.isEmpty(itemOrderSkuList)) {
                continue;
            }

            for (OrderSku orderSku : itemOrderSkuList) {

                // 赋值单价
                assignedUnitPrice(orderSku, bomBoMap);

                // 赋值包材费
                assignedPackagingMaterialCost(orderSku, saveOrderSkuBomList);

                // 赋值其他价格
                assignedOtherPrice(orderSku, orderInfo.getDepartmentId(), bomBoMap,
                        departmentIdPriceBillingStandardIdMap, priceBillingStandardMap, skuSpecMap);

                // 添加订单金额
                addOrderInfoPrice(orderInfo, orderSku);
            }

        }
    }

    /**
     * 赋值单价
     */
    private void assignedUnitPrice(OrderSku orderSku, Map<Long, BomBo> bomBoMap) {
        BomBo bomBo = bomBoMap.get(orderSku.getSkuSpecId());
        if (bomBo != null) {
            orderSku.setUnitPrice(ObjectUtil.defaultIfNull(bomBo.getInternalSellingPrice(), BigDecimal.ZERO));
        } else {
            orderSku.setUnitPrice(BigDecimal.ZERO);
        }
    }

    /**
     * 赋值包材费
     */
    private void assignedPackagingMaterialCost(OrderSku orderSku, List<OrderSkuBom> saveOrderSkuBomList) {
        BigDecimal packagingMaterialCost = saveOrderSkuBomList.stream()
                .filter(item -> Objects.equals(item.getOrderSkuId(), orderSku.getId()))
                .map(item -> item.getUnitPrice().multiply(item.getQuantity()))
                .reduce(BigDecimal.ZERO, BigDecimal::add);

        orderSku.setPackagingMaterialCost(packagingMaterialCost);
    }

    /**
     * 赋值其他价格
     */
    private void assignedOtherPrice(OrderSku orderSku,
                                    Long departmentId,
                                    Map<Long, BomBo> bomBoMap,
                                    Map<Long, Long> departmentIdPriceBillingStandardIdMap,
                                    Map<Long, List<PriceBillingStandardDetail>> priceBillingStandardMap,
                                    Map<String, SkuSpec> skuSpecMap) {

        orderSku.setCustomProcessingFee(BigDecimal.ZERO);
        orderSku.setLssueFee(BigDecimal.ZERO);
        orderSku.setDeliveryMaterialsFee(BigDecimal.ZERO);
        orderSku.setPackingLabor(BigDecimal.ZERO);

        // 没绑定bom规格，不赋值价格
        BomBo bomBo = bomBoMap.get(orderSku.getSkuSpecId());
        if (bomBo == null) {
            return;
        }

        // 如果bom规格不为主材，不赋值价格
        if (ObjectUtil.notEqual(bomBo.getClassifyParentId(), 1L)) {
            return;
        }

        // 获取加工计费标准id
        Long priceBillingStandardId = departmentIdPriceBillingStandardIdMap.get(departmentId);
        if (priceBillingStandardId == null) {
            return;
        }

        // 报价规则列表
        List<PriceBillingStandardDetail> priceBillingStandardDetailList = priceBillingStandardMap.get(priceBillingStandardId);
        if (ObjectUtil.isEmpty(priceBillingStandardDetailList)) {
            return;
        }

        for (PriceBillingStandardDetail priceBillingStandardDetail : priceBillingStandardDetailList) {

            String chargeItem = priceBillingStandardDetail.getChargeItem();
            BigDecimal chargePrice = ObjectUtil.defaultIfNull(priceBillingStandardDetail.getChargePrice(), BigDecimal.ZERO);

            switch (chargeItem) {
                case "40":
                    orderSku.setPackingLabor(chargePrice);
                    break;
                case "50":
                    orderSku.setLssueFee(chargePrice);
                    break;
                case "60":
                    orderSku.setDeliveryMaterialsFee(chargePrice);
                    break;
                default:
                    SkuSpec skuSpec = skuSpecMap.get(orderSku.getWlnSkuSpecId());
                    if (skuSpec != null
                            && Objects.equals(chargeItem, skuSpec.getMachinedPanel())
                            && orderSku.getQuantity().compareTo(priceBillingStandardDetail.getSectionMin()) >= 0
                            && orderSku.getQuantity().compareTo(priceBillingStandardDetail.getSectionMax()) < 0) {
                        orderSku.setCustomProcessingFee(chargePrice);
                    }
            }
        }
    }

    /**
     * 添加订单价格
     */
    private void addOrderInfoPrice(OrderInfo orderInfo, OrderSku orderSku) {
        BigDecimal quantity = orderSku.getQuantity();

        BigDecimal productTotalAmount = quantity.multiply(orderSku.getUnitPrice());
        BigDecimal customProcessingFee = quantity.multiply(orderSku.getCustomProcessingFee());
        BigDecimal lssueFee = quantity.multiply(orderSku.getLssueFee());
        BigDecimal deliveryMaterialsFee = quantity.multiply(orderSku.getDeliveryMaterialsFee());
        BigDecimal packingLabor = quantity.multiply(orderSku.getPackingLabor());
        BigDecimal packagingMaterialCost = quantity.multiply(orderSku.getPackagingMaterialCost());
        BigDecimal totalAmount = productTotalAmount
                .add(customProcessingFee)
                .add(lssueFee)
                .add(deliveryMaterialsFee)
                .add(packingLabor)
                .add(packagingMaterialCost);

        orderInfo.setProductTotalAmount(orderInfo.getProductTotalAmount().add(productTotalAmount));
        orderInfo.setCustomProcessingFee(orderInfo.getCustomProcessingFee().add(customProcessingFee));
        orderInfo.setLssueFee(orderInfo.getLssueFee().add(lssueFee));
        orderInfo.setDeliveryMaterialsFee(orderInfo.getDeliveryMaterialsFee().add(deliveryMaterialsFee));
        orderInfo.setPackingLabor(orderInfo.getPackingLabor().add(packingLabor));
        orderInfo.setPackagingMaterialCost(orderInfo.getPackagingMaterialCost().add(packagingMaterialCost));
        orderInfo.setTotalAmount(orderInfo.getTotalAmount().add(totalAmount));
    }

}
